@@ -1,5 +1,6 @@
 package Form::Factory::Control::Value;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
+
 
 use Moose;
 
@@ -17,7 +18,7 @@ Form::Factory::Control::Value - A read-only value control
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -51,14 +52,7 @@ has is_visible => (
     default   => 0,
 );
 
-=head2 value
-
-The value the control should have.
-
-=cut
-
-has value => (
-    is        => 'rw',
+has '+value' => (
     isa       => 'Str',
     required  => 1,
 );
@@ -83,7 +77,7 @@ Returns the L</value>.
 
 sub current_value { 
     my $self = shift;
-    $self->value(shift) if @_;
+    $self->value(@_) if @_;
     return $self->value;
 };
 
