@@ -1,5 +1,6 @@
 package Form::Factory::Feature::Role::Check;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
+
 
 use Moose::Role;
 
@@ -11,11 +12,14 @@ Form::Factory::Feature::Role::Check - features that check control values
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
   package MyApp::Feature::Bar;
+our $VERSION = '0.009';
+
+
   use Moose;
 
   with qw(
@@ -37,6 +41,12 @@ version 0.008
       }
   }
 
+  package Form::Factory::Feature::Custom::Bar;
+our $VERSION = '0.009';
+
+
+  sub register_implementation { 'MyApp::Feature::Bar' }
+
 =head1 DESCRIPTION
 
 Features that check the correctness of control values implement this role. This runs after input has been consumed and cleaned and before it is processed. The check here is meant to verify whether the input is valid and ready for processing. Mark the result as invalid to prevent processing. In general, it's a good idea to return an error if you do that. This is also a good place to return warnings.
