@@ -1,5 +1,6 @@
 package Form::Factory::Feature::Role::Clean;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
+
 
 use Moose::Role;
 
@@ -11,11 +12,14 @@ Form::Factory::Feature::Role::Clean - features that clean up control values
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
   package MyApp::Feature::Foo;
+our $VERSION = '0.009';
+
+
   use Moose;
 
   with qw(
@@ -30,6 +34,12 @@ version 0.008
       $self->control->{something}->current_value('Foo');
   }
 
+  package Form::Factory::Feature::Foo;
+our $VERSION = '0.009';
+
+
+  sub register_implementation { 'MyApp::Feature::Foo' }
+
 =head1 DESCRIPTION
 
 This is for features that run during the clean phase. This runs immediately after the input has been consumed and before it is checked. These features should avoid reporting errors. The intention is for these features to clean up the input automatically before it is checked for errors. This should work with the control values rather than the action attributes directly, since those won't be set yet.
