@@ -1,5 +1,6 @@
 package Form::Factory::Feature::Role::PostProcess;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
+
 
 use Moose::Role;
 
@@ -11,11 +12,14 @@ Form::Factory::Feature::Role::PostProcess - features that run just after process
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
   package MyApp::Feature::Qux;
+our $VERSION = '0.009';
+
+
   use Moose;
 
   with qw(
@@ -28,6 +32,12 @@ version 0.008
       MyApp::Logger->info('Ending the process.');
   }
 
+  package Form::Factory::Feature::Custom::Qux;
+our $VERSION = '0.009';
+
+
+  sub register_implementation { 'MyApp::Feature::Qux' }
+
 =head1 DESCRIPTION
 
 Features that run something immediately after the action runs may implement this role. This feature will run after the action does whether it succeeds or not. It will not run if an exception is thrown.
