@@ -1,5 +1,6 @@
 package Form::Factory::Feature::Role::PreProcess;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
+
 
 use Moose::Role;
 
@@ -11,11 +12,14 @@ Form::Factory::Feature::Role::PreProcess - features that run just before process
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
   package MyApp::Feature::Baz;
+our $VERSION = '0.009';
+
+
   use Moose;
 
   with qw(
@@ -28,6 +32,12 @@ version 0.008
       MyApp::Logger->info('Starting to process.');
   }
 
+  package Form::Factory::Feature::Custom::Baz;
+our $VERSION = '0.009';
+
+
+  sub register_implementation { 'MyApp::Feature::Baz' }
+
 =head1 DESCRIPTION
 
 Features that run something immediately before the action runs may implement this role. This feature cannot stop the action from running. That must be performed with a L<Form::Factory::Feature::Role::Check>.
